using JetBrains.Annotations;
using Orchard.ContentManagement;
using Orchard.ContentManagement.Drivers;
using Orchard.Localization;
using Orchard.UI.Notify;
using Mod.Training.Models;
using System.Collections.Generic;
using Mod.Training.Service;
using System.Linq;

namespace Mod.Training.Drivers
{
    [UsedImplicitly]
	
    public class ItemListPartDriver : ContentPartDriver<ItemListPart>
    {
        private readonly INotifier _notifier;
        private readonly ITrainingService tService;
        private const string TemplateName = "Parts/ItemListPart";

        public Localizer T { get; set; }

        public ItemListPartDriver(INotifier notifier, ITrainingService tService)
        {
            _notifier = notifier;
            this.tService = tService;
            T = NullLocalizer.Instance;
        }

        protected override DriverResult Display(ItemListPart part, string displayType, dynamic shapeHelper)
        {
            return ContentShape("Parts_ItemListPart",
                () => shapeHelper.Parts_ItemListPart(ContentItem: part.ContentItem));
        }

        protected override DriverResult Editor(ItemListPart part, dynamic shapeHelper)
        {

            //part.Items = tService.GetItems(23).ToList();

            //part.Items = items;

            return ContentShape("Parts_ItemListPart",
                    () => shapeHelper.EditorTemplate(TemplateName: TemplateName, Model: part, Prefix: Prefix));
        }

        protected override DriverResult Editor(ItemListPart part, IUpdateModel updater, dynamic shapeHelper)
        {
            if (updater.TryUpdateModel(part, Prefix, null, null))
            {
                _notifier.Information(T("ItemListPart edited successfully"));
            }
            else
            {
                _notifier.Error(T("Error during ItemListPart update!"));
            }
            return Editor(part, shapeHelper);
        }

    }
}